@@ -7,6 +7,7 @@ import {
   addDbEventListener,
   addModelEventListener,
 } from "./eventListeners.js";
+import morphdom from "./morphdom/2.6.1/morphdom.js";
 
 /**
  * Encapsulate component.
@@ -30,6 +31,7 @@ export class Component {
     this.document = args.document || document;
     this.walker = args.walker || walk;
     this.window = args.window || window;
+    this.morphdom = args.morphdom || morphdom;
 
     this.root = undefined;
     this.modelEls = [];
@@ -150,13 +152,15 @@ export class Component {
     };
     this.actionQueue.push(action);
 
-    this.queueMessage(-1, (triggeringElements, err) => {
+    this.queueMessage(-1, (triggeringElements, _, err) => {
       if (err && isFunction(errCallback)) {
         errCallback(err);
       } else if (err) {
         console.error(err);
       } else {
-        this.setModelValues(triggeringElements);
+        // Can hard-code `forceModelUpdate` to `true` since it is always required for
+        // `callMethod` actions
+        this.setModelValues(triggeringElements, true);
         this.setDbModelValues();
       }
     });
@@ -316,14 +320,17 @@ export class Component {
    * Sets all model values.
    * @param {[Element]} triggeringElements The elements that triggered the event.
    */
-  setModelValues(triggeringElements) {
+  setModelValues(triggeringElements, forceModelUpdates) {
     triggeringElements = triggeringElements || [];
+    forceModelUpdates = forceModelUpdates || false;
 
-    // Focus on the last element on what triggered the update.
+    let lastTriggeringElement = null;
+
+    // Focus on the last element which triggered the update.
     // Prevents validation errors from stealing focus.
     if (triggeringElements.length > 0) {
       let elementFocused = false;
-      const lastTriggeringElement = triggeringElements.slice(-1)[0];
+      lastTriggeringElement = triggeringElements.slice(-1)[0];
 
       if (
         hasValue(lastTriggeringElement) &&
@@ -347,7 +354,13 @@ export class Component {
     }
 
     this.modelEls.forEach((element) => {
-      this.setValue(element);
+      if (
+        forceModelUpdates ||
+        !lastTriggeringElement ||
+        !lastTriggeringElement.isSame(element)
+      ) {
+        this.setValue(element);
+      }
     });
   }
 
