@@ -69,12 +69,15 @@ export class Element {
       } else if (attribute.isPoll) {
         this.poll.method = attribute.value ? attribute.value : "refresh";
         this.poll.timing = 2000;
+        this.poll.disable = false;
 
         const pollArgs = attribute.name.split("-").slice(1);
 
         if (pollArgs.length > 0) {
           this.poll.timing = parseInt(pollArgs[0], 10) || 2000;
         }
+      } else if (attribute.isPollDisable) {
+        this.poll.disableData = attribute.value;
       } else if (attribute.isLoading) {
         if (attribute.modifiers.attr) {
           this.loading.attr = attribute.value;
