@@ -1,5 +1,4 @@
 import { getCsrfToken, hasValue, isFunction } from "./utils.js";
-import morphdom from "./morphdom/2.6.1/morphdom.js";
 import { MORPHDOM_OPTIONS } from "./morphdom/2.6.1/options.js";
 
 /**
@@ -16,6 +15,12 @@ export function send(component, callback) {
     return;
   }
 
+  // Since methods can change the data "behind the scenes", any queue with a callMethod
+  // action forces model elements to always be updated
+  const forceModelUpdate = component.actionQueue.some(
+    (a) => a.type === "callMethod"
+  );
+
   // Set the current action queue and clear the action queue in case another event happens
   component.currentActionQueue = component.actionQueue;
   component.actionQueue = [];
@@ -111,7 +116,7 @@ export function send(component, callback) {
         component.startPolling();
       }
 
-      morphdom(component.root, rerenderedComponent, MORPHDOM_OPTIONS);
+      component.morphdom(component.root, rerenderedComponent, MORPHDOM_OPTIONS);
 
       // Refresh the checksum based on the new data
       component.refreshChecksum();
@@ -136,7 +141,7 @@ export function send(component, callback) {
       component.currentActionQueue = null;
 
       if (isFunction(callback)) {
-        callback(triggeringElements, null);
+        callback(triggeringElements, forceModelUpdate, null);
       }
     })
     .catch((err) => {
