@@ -1,3 +1,5 @@
+from typing import Dict
+
 from django import template
 from django.conf import settings
 
@@ -5,7 +7,6 @@ import shortuuid
 
 from django_unicorn.call_method_parser import InvalidKwarg, parse_kwarg
 
-
 from ..settings import get_setting
 
 
@@ -53,9 +54,13 @@ def unicorn(parser, token):
 
 
 class UnicornNode(template.Node):
-    def __init__(self, component_name, kwargs):
+    def __init__(self, component_name: str, kwargs: Dict):
         self.component_name = component_name
         self.kwargs = kwargs
+        self.component_key = ""
+
+        if "key" in kwargs:
+            self.component_key = kwargs.pop("key")
 
     def render(self, context):
         request = None
@@ -76,9 +81,11 @@ class UnicornNode(template.Node):
                 resolved_kwargs.update({key: val})
 
         from ..components import UnicornView
+
         view = UnicornView.create(
             component_id=component_id,
             component_name=self.component_name,
+            component_key=self.component_key,
             kwargs=resolved_kwargs,
             request=request,
         )
